// Force strict mode and setup for ESM
"use strict";
import {
  init_esbuild_shims
} from "./chunk-5O2XNYP6.js";

// packages/core/src/plan-gate/types.ts
init_esbuild_shims();
var CAPPED_REVIEW_LIMIT = 5;
var MAX_AGENT_RETRIES = 3;
var CAP_ESCALATION_LABELS = {
  CONTINUE: "Continue editing plan",
  APPROVE: "Approve execution"
};

export {
  CAPPED_REVIEW_LIMIT,
  MAX_AGENT_RETRIES,
  CAP_ESCALATION_LABELS
};
/**
 * @license
 * Copyright 2025 Qwen
 * SPDX-License-Identifier: Apache-2.0
 */
