import{s as a,c as s,a as e,C as t}from"./chunk-727SXJPM-CYEeAamv.js";import{_ as i}from"./mermaid.core-BV5o7nW5.js";import"./chunk-FMBD7UC4-CGZKk4PH.js";import"./chunk-ND2GUHAM-qQbC2O-y.js";import"./chunk-55IACEB6-DT713sZf.js";import"./chunk-2J33WTMH-xKmLg7Yr.js";import"./index-KFJRDhX7.js";var n={parser:e,get db(){return new t},renderer:s,styles:a,init:i(r=>{r.class||(r.class={}),r.class.arrowMarkerAbsolute=r.arrowMarkerAbsolute},"init")};export{n as diagram};
